==> BioPerl-1.5.9_2.tar.gz: BioPerl-1.5.9._2/Bio/Coordinate/Result/Match.pm <==
# $Id: Match.pm 11480 2007-06-14 14:16:21Z sendu $
#
# BioPerl module for Bio::Coordinate::Result::Match
#
# Cared for by Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
#
# Copywright Heikki Lehvaslaiho
#
# You may distribute this module under the same terms as perl itself
#
# POD documentation - main docs before the code
#

=head1 NAME

Bio::Coordinate::Result::Match - Another name for Bio::Location::Simple

=head1 SYNOPSIS

  $loc = Bio::Coordinate::Result::Match->new(-start=>10,
                                            -end=>30,
                                            -strand=>+1);

=head1 DESCRIPTION

This is a location class for coordinate mapping results.

=head1 FEEDBACK

=head2 Mailing Lists

User feedback is an integral part of the evolution of this and other
Bioperl modules. Send your comments and suggestions preferably to one
of the Bioperl mailing lists.  Your participation is much appreciated.

  bioperl-l@bioperl.org                  - General discussion
  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists

=head2 Reporting Bugs

Report bugs to the Bioperl bug tracking system to help us keep track
the bugs and their resolution.  Bug reports can be submitted via the
web:

  http://bugzilla.open-bio.org/

=head1 AUTHOR - Heikki Lehvaslaiho

Email heikki-at-bioperl-dot-org

=head1 APPENDIX

The rest of the documentation details each of the object
methods. Internal methods are usually preceded with a _

=cut

package Bio::Coordinate::Result::Match;
use strict;


use base qw(Bio::Location::Simple Bio::Coordinate::ResultI);


1;

==> BioPerl-1.6.1.tar.gz: BioPerl-1.6.1/Bio/Coordinate/Result/Match.pm <==
# $Id: Match.pm 16123 2009-09-17 12:57:27Z cjfields $
#
# BioPerl module for Bio::Coordinate::Result::Match
#
# Please direct questions and support issues to <bioperl-l@bioperl.org> 
#
# Cared for by Heikki Lehvaslaiho <heikki-at-bioperl-dot-org>
#
# Copywright Heikki Lehvaslaiho
#
# You may distribute this module under the same terms as perl itself
#
# POD documentation - main docs before the code
#

=head1 NAME

Bio::Coordinate::Result::Match - Another name for Bio::Location::Simple

=head1 SYNOPSIS

  $loc = Bio::Coordinate::Result::Match->new(-start=>10,
                                            -end=>30,
                                            -strand=>+1);

=head1 DESCRIPTION

This is a location class for coordinate mapping results.

=head1 FEEDBACK

=head2 Mailing Lists

User feedback is an integral part of the evolution of this and other
Bioperl modules. Send your comments and suggestions preferably to one
of the Bioperl mailing lists.  Your participation is much appreciated.

  bioperl-l@bioperl.org                  - General discussion
  http://bioperl.org/wiki/Mailing_lists  - About the mailing lists

=head2 Support 

Please direct usage questions or support issues to the mailing list:

I<bioperl-l@bioperl.org>

rather than to the module maintainer directly. Many experienced and 
reponsive experts will be able look at the problem and quickly 
address it. Please include a thorough description of the problem 
with code and data examples if at all possible.

=head2 Reporting Bugs

Report bugs to the Bioperl bug tracking system to help us keep track
the bugs and their resolution.  Bug reports can be submitted via the
web:

  http://bugzilla.open-bio.org/

=head1 AUTHOR - Heikki Lehvaslaiho

Email heikki-at-bioperl-dot-org

=head1 APPENDIX

The rest of the documentation details each of the object
methods. Internal methods are usually preceded with a _

=cut

package Bio::Coordinate::Result::Match;
use strict;


use base qw(Bio::Location::Simple Bio::Coordinate::ResultI);


1;
